@@ -320,6 +320,10 @@ def visualize_gan(argv = []):
     # sys.argv = ["csv_file", "file=sd_len100_10000ep_cond0_20k.csv", "training_file=generated_samples\sd_len100_10000ep_cond1_20k.csv", "pca"]
     default_args = system_inputs.parse_arguments(argv, file='Visualize_Gan.py')
 
+    # Shut down if default args = "help"
+    if default_args == 'help':
+        return []
+        
     print('\n-----------------------------------------')
     print("System output:")
     print('-----------------------------------------\n')
