@@ -1,4 +1,4 @@
 from eeggan.Train_Gan import train_gan
 from eeggan.Visualize_Gan import visualize_gan
 from eeggan.Generate_Samples import generate_samples
-from eeggan.Load_Tutorial_File import load_tutorial_file
\ No newline at end of file
+from eeggan.Setup_Tutorial import setup_tutorial
\ No newline at end of file
